Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetCommandVerb ¶
GetCommandVerb extracts the kubectl verb from a command string
func GetResourceTypes ¶
func GetResourceTypes() []string
GetResourceTypes returns a list of common resource types
func IsDestructive ¶
IsDestructive checks if a command is destructive (requires confirmation)
Types ¶
type ExecuteResult ¶
type ExecuteResult struct {
Stdout string
Stderr string
ExitCode int
Duration time.Duration
Error error
}
ExecuteResult contains the result of a kubectl execution
type Executor ¶
type Executor struct {
// contains filtered or unexported fields
}
Executor executes kubectl commands
func (*Executor) Execute ¶
func (e *Executor) Execute(ctx context.Context, args []string) *ExecuteResult
Execute runs a kubectl command
func (*Executor) ExecuteStreaming ¶ added in v1.1.0
ExecuteStreaming runs a command and streams output via tea messages
func (*Executor) ExecuteString ¶
func (e *Executor) ExecuteString(ctx context.Context, command string) *ExecuteResult
ExecuteString runs a command from a string. Commands starting with "!" are executed directly in the shell, all others are treated as kubectl commands.
type PaneCompleteMsg ¶ added in v1.1.0
PaneCompleteMsg indicates a pane command has completed
Click to show internal directories.
Click to hide internal directories.